@@ -83,7 +83,8 @@ void MBoxPrivate::unlockMBox()
 QByteArray MBoxPrivate::mboxMessageSeparator(const QByteArray &msg)
 {
     KMime::Message mail;
-    QByteArray body, header;
+    QByteArray body;
+    QByteArray header;
     KMime::HeaderParsing::extractHeaderAndBody(KMime::CRLFtoLF(msg), header, body);
     body.clear();
     mail.setHead(header);
@@ -127,7 +128,7 @@ QByteArray MBoxPrivate::escapeFrom(const QByteArray &str)
     const char *const e = s + strLen - STRDIM("From ");
     char *d = result.data();
 
-    bool onlyAnglesAfterLF = false; // dont' match ^From_
+    bool onlyAnglesAfterLF = false; // don't match ^From_
     while (s < e) {
         switch (*s) {
         case '\n':
